@@ -25,7 +25,6 @@
 #include <X11/keysym.h>
 
 #include <glib/gi18n.h>
-#include <libgnome/gnome-program.h>
 
 #include <gkbd-keyboard-config.h>
 #include <gkbd-config-private.h>
@@ -794,12 +793,10 @@ gkbd_keyboard_config_to_string (const GkbdKeyboardConfig * config)
 					 (const gchar *) iter->data);
 		}
 
-		/* TRANS: The count is related to the number of options. The %s format specifier should not be modified,
-		 * left "as is". */
-		layouts =
-		    g_strdup_printf (ngettext
-				     ("layout \"%s\"", "layouts \"%s\"",
-				      count), buffer->str);
+		/* Translators: The count is related to the number of options. The %s
+		 * format specifier should not be modified, left "as is". */
+		layouts = g_strdup_printf (ngettext ("layout \"%s\"", "layouts \"%s\"",
+					count), buffer->str);
 		g_string_truncate (buffer, 0);
 	}
 	if (config->options) {
@@ -813,12 +810,10 @@ gkbd_keyboard_config_to_string (const GkbdKeyboardConfig * config)
 					 (const gchar *) iter->data);
 		}
 
-		/* TRANS: The count is related to the number of options. The %s format specifier should not be modified,
-		 * left "as is". */
-		options =
-		    g_strdup_printf (ngettext
-				     ("option \"%s\"", "options \"%s\"",
-				      count), buffer->str);
+		/* Translators: The count is related to the number of options. The %s
+		 * format specifier should not be modified, left "as is". */
+		options = g_strdup_printf (ngettext ("option \"%s\"", "options \"%s\"",
+					count), buffer->str);
 		g_string_truncate (buffer, 0);
 	}
 
